@@ -3,8 +3,8 @@
 != Test program for "gt4_history_nmlinfo" 
 !
 ! Authors::   Yasuhiro MORIKAWA
-! Version::   $Id: gt4_history_nmlinfo_test.f90,v 1.15 2008-07-18 13:30:54 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20080720 $
+! Version::   $Id: gt4_history_nmlinfo_test.f90,v 1.16 2008-08-10 16:37:39 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20080810 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2007. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -44,7 +44,7 @@ program gt4_history_nmlinfo_test
   !  Title of a experiment, name of model, sub-organ
   !-------------------------------------------------------------------
   character(*), parameter:: title = &
-    & 'gt4_history_nmlinfo_test $Name: gt4f90io-20080720 $ :: ' // &
+    & 'gt4_history_nmlinfo_test $Name: gt4f90io-20080810 $ :: ' // &
     & 'Test program of "gt4_history_nmlinfo" module'
   character(*), parameter:: source = &
     & 'gtool4 project ' // &
@@ -92,6 +92,9 @@ program gt4_history_nmlinfo_test
   character(STRING):: varnames
                               ! ѿ̾ꥹ. 
                               ! List of variables
+  character(TOKEN), pointer:: varnames_array(:) =>null()
+                              ! ѿ̾ꥹ. 
+                              ! List of variables
 
   type(GT_HISTORY), pointer:: history00 =>null()
                               ! gt4_history ⥸塼ѹ¤. 
@@ -522,10 +525,11 @@ continue
   !  names ƥ
   !  "names" test
   !-------------------------------------------------------------------
-  varnames = HstNmlInfoNames( gthstnml06 )
+  call HstNmlInfoNames( gthstnml06, & ! (in)
+    & varnames_array, err )           ! (out)
 
   call AssertEqual( '"names" test 1-1', &
-    & answer = '', check = varnames )
+    & answer = .true., check = err )
 
   call HstNmlInfoCreate( &
     & gthstnml = gthstnml06, & ! (out)
@@ -554,10 +558,12 @@ continue
 
   call HstNmlInfoPutLine( gthstnml = gthstnml06 ) ! (in)
 
-  varnames = HstNmlInfoNames( gthstnml06 )
+  call HstNmlInfoNames( gthstnml06, & ! (in)
+    & varnames_array )                ! (out)
 
   call AssertEqual( '"names" test 1-2', &
-    & answer = 'Data1,Data2,Data4,Data5', check = varnames )
+    & answer = (/ 'Data1', 'Data2', 'Data4', 'Data5' /), check = varnames_array )
+  deallocate( varnames_array )
 
   call HstNmlInfoClose( gthstnml = gthstnml06 ) ! (inout)
 
@@ -583,10 +589,12 @@ continue
 
   call HstNmlInfoPutLine( gthstnml = gthstnml07 ) ! (in)
 
-  varnames = HstNmlInfoNames( gthstnml07 )
+  call HstNmlInfoNames( gthstnml07, & ! (in)
+    & varnames_array )                ! (out)
 
   call AssertEqual( '"ResetDefault" test 1-1', &
-    & answer = '', check = varnames )
+    & answer = (/ '' /), check = varnames_array )
+  deallocate( varnames_array )
 
   call AssertEqual( '"ResetDefault" test 1-2', &
     & answer = .true., check = HstNmlInfoInitialized( gthstnml07 ) )
@@ -626,10 +634,12 @@ continue
 
   call HstNmlInfoPutLine( gthstnml = gthstnml08 ) ! (in)
 
-  varnames = HstNmlInfoNames( gthstnml08 )
+  call HstNmlInfoNames( gthstnml08, & ! (in)
+    & varnames_array )                ! (out)
 
   call AssertEqual( 'multiple variables handling test 1-1', &
-    & answer = 'Data1,Data2,Data3,Data4', check = varnames )
+    & answer = (/ 'Data1', 'Data2', 'Data3', 'Data4' /), check = varnames_array )
+  deallocate( varnames_array )
 
   call HstNmlInfoDelete( &
     & gthstnml = gthstnml08, & ! (inout)
@@ -637,10 +647,12 @@ continue
 
   call HstNmlInfoPutLine( gthstnml = gthstnml08 ) ! (in)
 
-  varnames = HstNmlInfoNames( gthstnml08 )
+  call HstNmlInfoNames( gthstnml08, & ! (in)
+    & varnames_array )                ! (out)
 
   call AssertEqual( 'multiple variables handling test 1-1', &
-    & answer = 'Data1,Data4', check = varnames )
+    & answer = (/ 'Data1', 'Data4' /), check = varnames_array )
+  deallocate( varnames_array )
 
   call HstNmlInfoClose( gthstnml = gthstnml08 ) ! (inout)
 
